plot.mritc: Plot Method for Class "mritc"

View source: R/plot.mritc.R

plot.mritcR Documentation

Plot Method for Class "mritc"

Description

Visualize MRI tissue classification results.

Usage

   ## S3 method for class 'mritc'
plot(x, method=c("RNifti","misc3d"), ...)

Arguments

x

an object of class "mritc"

method

the visualisation backend to use. The default, "RNifti", uses view; the alternative, "misc3d", uses the three-plane Tk-based viewer slices3d, which requires the tkrplot tcltk packages to be installed and useable.

...

any additional arguments for the relevant viewer.

Details

Allocate a voxel to the tissue type with the highest probability and then visualise the result.

Value

NULL, invisibly

Note

Prior to version 0.6.0, "misc3d" was the only viewer supported, but owing to its system requirements "RNifti" was added as a new default for better portability.

See Also

view, slices3d

Examples

  T1 <- readMRI(system.file("extdata/t1.rawb.gz", package="mritc"),
                c(91,109,91), format="rawb.gz")
  mask <-readMRI(system.file("extdata/mask.rawb.gz", package="mritc"),
                 c(91,109,91), format="rawb.gz")
  tc.icm <- mritc(T1, mask, method="ICM")
  plot(tc.icm)

mritc documentation built on July 25, 2026, 9:06 a.m.