Learn R Programming

mritc (version 0.3-2)

print.mritc: Print Method for Class "mritc"

Description

Print out some information of an object of class "mritc".

Usage

print.mritc(x, ...)

Arguments

x
an object of class "mritc".
...
any additional arguments.

Value

  • The function computes and returns some summary statistics of the object obtained from running the function mritc.

Examples

Run this code
T1 <- readMRI(system.file("extdata/t1.rawb.gz", package="mritc"),
                c(91,109,91), format="rawb.gz")
  mask <-readMRI(system.file("extdata/mask.rawb.gz", package="mritc"),
                 c(91,109,91), format="rawb.gz")
  tc.icm <- mritc(T1, mask, method="ICM")
  tc.icm

Run the code above in your browser using DataLab