Learn R Programming

mritc (version 0.6.1)

rnormmix: Generate Random Samples from a Normal Mixture Model

Description

Generate random samples from a normal mixture model.

Usage

rnormmix(n, prop, mu, sigma)

Value

A matrix with each row corresponding to one sample. The first column are sample values from a normal mixture model; the second column are the components from which observations come.

Arguments

n

number of observations.

prop

a vector of proportions of different components.

mu

a vector of means of different components.

sigma

a vector of standard deviations of different components

Examples

Run this code
  prop <- c(.17, .48, .35)
  mu <- c(-4, 0, 4)
  sigma <- rep(1, 3)
  y <- rnormmix(n=10000, prop, mu, sigma)
  hist(y[,1], breaks=50)

Run the code above in your browser using DataLab